# QC Result Viewer

Disclaimer:
Please note that this website will access and interpret the files you select. The interpretation will happen locally in your browser.
- If you select a file from your local machine, the data will remain local and will not be sent to the server.
- If you load data from the repository, the website will fetch the relevant QC results directly from the server.
  This does not involve submitting any personal or sensitive data to the server.
  The data retrieved will only be used for local interpretation and display within your browser.
By making use of the file selection or repository-based selection, you acknowledge that you understand and agree to these terms.

## Load QC Results From Repository:

## Or Select a Local QC Summary File: